summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--sys/scsi/cd.c11
-rw-r--r--sys/scsi/cd.h16
2 files changed, 6 insertions, 21 deletions
diff --git a/sys/scsi/cd.h b/sys/scsi/cd.h
index d0a4e3646b1..5965b6a7153 100644
--- a/sys/scsi/cd.h
+++ b/sys/scsi/cd.h
@@ -1,4 +1,4 @@
-/* $OpenBSD: cd.h,v 1.15 2007/05/27 01:15:32 mjc Exp $ */
+/* $OpenBSD: cd.h,v 1.16 2008/06/17 01:32:49 krw Exp $ */
/* $NetBSD: scsi_cd.h,v 1.6 1996/03/19 03:06:39 mycroft Exp $ */
/*
@@ -158,14 +158,6 @@ struct scsi_read_track_info {
u_int8_t control;
};
-struct scsi_read_cd_capacity {
- u_int8_t opcode;
- u_int8_t byte2;
- u_int8_t addr[4];
- u_int8_t unused[3];
- u_int8_t control;
-};
-
struct scsi_load_unload {
u_int8_t opcode;
u_int8_t reserved;
@@ -195,7 +187,6 @@ struct scsi_set_cd_speed {
* Opcodes
*/
-#define READ_CD_CAPACITY 0x25 /* slightly different from disk */
#define READ_SUBCHANNEL 0x42 /* cdrom read Subchannel */
#define READ_TOC 0x43 /* cdrom read TOC */
#define READ_HEADER 0x44 /* cdrom read header */
@@ -220,11 +211,6 @@ struct scsi_set_cd_speed {
#define WRITE_PARAM_PAGE 0x05
#define CDVD_CAPABILITIES_PAGE 0x2a
-struct scsi_read_cd_cap_data {
- u_int8_t addr[4];
- u_int8_t length[4];
-};
-
struct cd_audio_page {
u_int8_t page_code;
#define CD_PAGE_CODE 0x3F
diff --git a/sys/scsi/cd.c b/sys/scsi/cd.c
index 6ccba930625..58c2facee6c 100644
--- a/sys/scsi/cd.c
+++ b/sys/scsi/cd.c
@@ -1,4 +1,4 @@
-/* $OpenBSD: cd.c,v 1.138 2008/06/15 00:36:41 krw Exp $ */
+/* $OpenBSD: cd.c,v 1.139 2008/06/17 01:32:49 krw Exp $ */
/* $NetBSD: cd.c,v 1.100 1997/04/02 02:29:30 mycroft Exp $ */
/*
@@ -1180,13 +1180,12 @@ done:
u_long
cd_size(struct cd_softc *cd, int flags)
{
- struct scsi_read_cd_cap_data rdcap;
- struct scsi_read_cd_capacity scsi_cmd;
+ struct scsi_read_cap_data rdcap;
+ struct scsi_read_capacity scsi_cmd;
u_long size;
int blksize;
- /* Reasonable defaults for drives that don't support
- READ_CD_CAPACITY */
+ /* Reasonable defaults for drives that don't support READ_CAPACITY */
cd->params.blksize = 2048;
cd->params.disksize = 400000;
@@ -1198,7 +1197,7 @@ cd_size(struct cd_softc *cd, int flags)
* it for you.
*/
bzero(&scsi_cmd, sizeof(scsi_cmd));
- scsi_cmd.opcode = READ_CD_CAPACITY;
+ scsi_cmd.opcode = READ_CAPACITY;
/*
* If the command works, interpret the result as a 4 byte